@@ -42,7 +42,7 @@ class Command(BaseCommand):
         for mf in model_fields:
             field, data_type, *relationship = re.split(r'[:=]', mf)
 
-            if data_type.startswith("date"): import_timezone = True
+            if data_type.startswith("date") or data_type == "dt": import_timezone = True
             if relationship: relationship = relationship[0]
             _field_template += _helper.MODEL_FIELD_TEMPLATE.format(field, _helper.FIELD_MAPPERS[data_type].format(relationship))
 
